@@ -659,7 +659,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 	.. versionadded:: 2.0.0
 	"""  # noqa: D400
 
-	def check(self, page: BeautifulSoup, **kwargs):  # type: ignore
+	def check(self, page: BeautifulSoup, *, extension: str = ".html", **kwargs):  # type: ignore
 		r"""
 		Check an HTML page generated by Sphinx for regressions,
 		using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`_
@@ -692,7 +692,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 		super().check(
 				str(StringList(page.prettify())),
 				encoding="UTF-8",
-				extension=".html",
+				extension=extension,
 				)
 
 
